pynrc.simul.apt
===============

.. automodule:: pynrc.simul.apt

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
      :toctree:
   
      build_dict_from_xml
      create_det_class
      create_obs_params
      file_segmenting
      gen_all_apt_visits
      gen_jwst_pointing
      gen_pointing_info
      get_ditherinfo
      get_exp_type
      get_filter_info
      get_orient_specreq
      get_pointing_info
      get_proposal_info
      get_readmodes
      get_roll_info
      get_siaf_detectors
      get_target_info
      get_tel_angles
      get_timing_info
      pitch_vs_time
      populate_obs_params
      read_subarray_definition_file
      update_eng_detectors
      update_subarray_imaging
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :toctree:
      :template: custom-class-template.rst
   
      AptInput
      DMS_input
      ReadAPTXML
   
   

   
   
   



